package com.agilecontrol.nea.core.security;

import com.agilecontrol.nea.core.schema.ClientManager;
import com.agilecontrol.nea.core.security.pwd.PwdEncryptor;
import com.agilecontrol.nea.util.NDSRuntimeException;
import java.util.Date;
import java.util.Locale;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class User {

   private static Logger logger = LoggerFactory.getLogger(User.class);
   private Integer id = Integer.valueOf(1);
   private String name;
   private String truename;
   private volatile String passwordHash;
   private int isEnabled;
   private boolean isActive;
   private int isEmployee;
   private boolean isAdmin;
   private String description;
   private int adClientId;
   private int adOrgId;
   private Locale locale;
   private String email;
   private long passwordExpireDateTime;
   private int securityGrade;
   private boolean isPwdExpired = false;
   private volatile String pwdRand;
   private int failedloginattempts;
   private int mbrId;
   private Object props;


   public Object getProps() {
      return this.props;
   }

   public void setProps(Object obj) {
      this.props = obj;
   }

   public int getMemberId() {
      return this.mbrId;
   }

   public void setMemberId(int mbrId) {
      this.mbrId = mbrId;
   }

   public boolean isGuest() {
      return this.id.intValue() == 1;
   }

   public Integer getId() {
      return this.id;
   }

   void setId(Integer id) {
      this.id = id;
   }

   public String getName() {
      return this.name;
   }

   void setName(String name) {
      this.name = name;
   }

   public String getPasswordHash() {
      return this.passwordHash;
   }

   void setPasswordHash(String passwordHash) {
      this.passwordHash = passwordHash;
   }

   public int getIsEnabled() {
      return this.isEnabled;
   }

   void setIsEnabled(int isEnabled) {
      this.isEnabled = isEnabled;
   }

   public int getIsEmployee() {
      return this.isEmployee;
   }

   void setIsEmployee(int isEmployee) {
      this.isEmployee = isEmployee;
   }

   public boolean isAdmin() {
      return this.isAdmin;
   }

   void setIsAdmin(int isAdmin) {
      this.isAdmin = isAdmin == 1;
   }

   public String getDescription() {
      return this.description;
   }

   void setDescription(String description) {
      this.description = description;
   }

   public String toString() {
      return this.id == null?"":this.id.toString();
   }

   public boolean isActive() {
      return this.isActive;
   }

   void setActive(boolean isActive) {
      this.isActive = isActive;
   }

   public int getSecurityGrade() {
      return this.securityGrade;
   }

   void setSecurityGrade(int securityGrade) {
      this.securityGrade = securityGrade;
   }

   public long getPassordExpireDateTime() {
      return this.passwordExpireDateTime;
   }

   void setPasswordExpireDateTime(Date expireDateTime) {
      if(expireDateTime != null) {
         this.passwordExpireDateTime = expireDateTime.getTime();
         if(this.passwordExpireDateTime > 0L && this.passwordExpireDateTime < System.currentTimeMillis()) {
            this.isPwdExpired = true;
         }

      }
   }

   public boolean isPasswordExpired() {
      return this.isPwdExpired;
   }

   public String getPwdRand(boolean flag) {
      return flag?this.pwdRand:null;
   }

   void setPwdRand(String pwdRand) {
      this.pwdRand = pwdRand;
   }

   public boolean isValidPassword(String plainPassword) {
      try {
         String ex = PwdEncryptor.encrypt(plainPassword, this.pwdRand);
         boolean b = ex.equals(this.passwordHash);
         if(!b) {
            logger.debug("invalid password ");
         }

         return b;
      } catch (Exception var4) {
         throw new NDSRuntimeException("Could not validate password:" + var4);
      }
   }

   public int getFailedLoginAttempts() {
      return this.failedloginattempts;
   }

   void setFailedLoginAttempts(int failedloginattempts) {
      this.failedloginattempts = failedloginattempts;
   }

   void setClientId(int cid) {
      this.adClientId = cid;
   }

   public int getClientId() {
      return this.adClientId;
   }

   void setOrgId(int orgId) {
      this.adOrgId = orgId;
   }

   public int getOrgId() {
      return this.adOrgId;
   }

   void setLocale(Locale loc) {
      this.locale = loc;
   }

   public Locale getLocale() {
      return this.locale;
   }

   void setEmail(String ma) {
      this.email = ma;
   }

   public String getEmail() {
      return this.email;
   }

   void setTrueName(String ma) {
      this.truename = ma;
   }

   public String getTrueName() {
      return this.truename;
   }

   public String getClientDomain() {
      try {
         return ClientManager.getInstance().getClient(this.adClientId).getDomain();
      } catch (Throwable var2) {
         throw new NDSRuntimeException(var2.getMessage());
      }
   }

   public String getNameWithDomain() {
      return this.name + "@" + this.getClientDomain();
   }

}
